@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 sub engine {
     my $class = shift;
@@ -42,25 +42,25 @@ Search::OpenSearch - provide search results in OpenSearch format
     fields  => [qw( color size flavor )],
  );
  my $response = $engine->search(
-    q           => 'quick brown fox',   # query
-    s           => 'rank desc',         # sort order
-    o           => 0,                   # offset
-    p           => 25,                  # page size
-    h           => 1,                   # highlight query terms in results
-    c           => 0,                   # count total only (same as f=0 r=0)
-    L           => 'field|low|high',    # limit results to inclusive range
-    f           => 1,                   # include facets
-    r           => 1,                   # include results
-    format      => 'XML',               # or JSON
-    b           => 'AND',               # or OR
+    q   => 'quick brown fox',   # query
+    s   => 'rank desc',         # sort order
+    o   => 0,                   # offset
+    p   => 25,                  # page size
+    h   => 1,                   # highlight query terms in results
+    c   => 0,                   # count total only (same as f=0 r=0)
+    L   => 'field|low|high',    # limit results to inclusive range
+    f   => 1,                   # include facets
+    r   => 1,                   # include results
+    t   => 'XML',               # or JSON
+    u   => 'http://yourdomain.foo/opensearch/',
+    b   => 'AND',               # or OR
+    x   => [qw( foo bar )],     # return only a subset of fields
  );
  print $response;
 
 =head1 DESCRIPTION
 
-This module is a work-in-progress. The API is subject to change.
-
-Search::OpenSearch is a framework for various backend engines
+Search::OpenSearch is a framework for search engines
 to return results comforming to the OpenSearch API (http://opensearch.org/).
 
 =head1 METHODS
